@@ -1,43 +1,62 @@
 import base64
+import mimetypes
+from typing import Optional
 
 from google.genai import types
 
 from llm_bridge.client.implementations.gemini.gemini_token_counter import count_gemini_tokens
 from llm_bridge.client.implementations.printing_status import PrintingStatus
-from llm_bridge.type.chat_response import Citation, ChatResponse
+from llm_bridge.type.chat_response import Citation, ChatResponse, File
 
 
 class GeminiResponseHandler:
     def __init__(self):
-        self.printing_status = None
-        self.prev_output_tokens = 0
-        self.prev_printing_status = None
+        self.printing_status: Optional[PrintingStatus] = None
+        self.prev_output_tokens: int = 0
+        self.prev_printing_status: Optional[PrintingStatus] = None
 
     async def process_gemini_response(
             self,
             response: types.GenerateContentResponse,
     ) -> ChatResponse:
-        text = ""
-        display = None
-        image_base64 = None
-        citations = extract_citations(response)
+        text: str = ""
+        thought: str = ""
+        code: str = ""
+        code_output: str = ""
+        files: list[File] = []
+        display: Optional[str] = None
+        citations: list[Citation] = extract_citations(response)
         input_tokens, stage_output_tokens = await count_gemini_tokens(response)
 
+        printing_status = None
         if candidates := response.candidates:
             if candidates[0].content.parts:
                 for part in response.candidates[0].content.parts:
-                    # Thought Output
-                    if part.text:
-                        if part.thought and not self.printing_status:
-                            text += "# Model Thought:\n\n"
-                            self.printing_status = PrintingStatus.Thought
-                        elif not part.thought and self.printing_status == PrintingStatus.Thought:
-                            text += f"\n\n# Model Response:\n\n"
-                            self.printing_status = PrintingStatus.Response
-                        text += part.text
-                    # Image Output
-                    elif part.inline_data:
-                        image_base64 = base64.b64encode(part.inline_data.data).decode('utf-8')
+                    if part.text is not None:
+                        # Thought
+                        if part.thought:
+                            printing_status = PrintingStatus.Thought
+                            thought += part.text
+                        # Text
+                        elif not part.thought:
+                            printing_status = PrintingStatus.Response
+                            text += part.text
+                    # Code
+                    if part.executable_code is not None:
+                        code += part.executable_code.code
+                    # Code Output
+                    if part.code_execution_result is not None:
+                        code_output += part.code_execution_result.output
+                    # File
+                    if part.inline_data is not None:
+                        mime_type = part.inline_data.mime_type
+                        extension = mimetypes.guess_extension(mime_type) or ""
+                        file = File(
+                            name=f"generated_file{extension}",
+                            data=base64.b64encode(part.inline_data.data).decode('utf-8'),
+                            type=mime_type,
+                        )
+                        files.append(file)
 
         # Grounding Sources
         if candidates := response.candidates:
@@ -50,17 +69,20 @@ class GeminiResponseHandler:
                         if chunk.web:
                             text += f"{i}. [{chunk.web.title}]({chunk.web.uri})\n"
 
-        if self.printing_status == self.prev_printing_status:
+        if printing_status == self.prev_printing_status and printing_status == PrintingStatus.Response:
             output_tokens = stage_output_tokens - self.prev_output_tokens
         else:
             output_tokens = stage_output_tokens
 
         self.prev_output_tokens = stage_output_tokens
-        self.prev_printing_status = self.printing_status
+        self.prev_printing_status = printing_status
 
         return ChatResponse(
             text=text,
-            image=image_base64,
+            thought=thought,
+            code=code,
+            code_output=code_output,
+            files=files,
             display=display,
             citations=citations,
             input_tokens=input_tokens,
@@ -77,4 +99,4 @@ def extract_citations(response: types.GenerateContentResponse) -> list[Citation]
                     citation_indices = [index + 1 for index in grounding_support.grounding_chunk_indices]
                     citation_text = grounding_support.segment.text
                     citations.append(Citation(text=citation_text, indices=citation_indices))
-    return citations
\ No newline at end of file
+    return citations
