@@ -35,7 +35,7 @@ def count_openai_responses_input_tokens(messages: list[OpenAIResponsesMessage])
 
 def count_openai_output_tokens(chat_response: ChatResponse) -> int:
     text = chat_response.text
-    file_count = 1 if chat_response.image else 0
+    file_count = len(chat_response.files)
 
     return num_tokens_from_text(text) + file_count * 1000
 
